=========
Reference
=========

Manipulation of strings
-----------------------

.. autoclass:: hanabython.StringAnsi
    :members:

.. autofunction:: hanabython.str_from_iterable

.. autofunction:: hanabython.title

.. autofunction:: hanabython.uncolor

.. autoclass:: hanabython.Colored
    :members:

Colors
------

.. autoclass:: hanabython.Color
    :members:

.. autoclass:: hanabython.ColorMulticolor
    :members:

.. autoclass:: hanabython.ColorColorless
    :members:

.. autoclass:: hanabython.ColorBook
    :members:

Configuration
-------------

.. autoclass:: hanabython.ConfigurationColorContents
    :members:

.. autoclass:: hanabython.ConfigurationDeck
    :members:

.. autoclass:: hanabython.ConfigurationEmptyClueRule
    :members:

.. autoclass:: hanabython.ConfigurationEndRule
    :members:

.. autoclass:: hanabython.ConfigurationHandSize
    :members:

.. autoclass:: hanabython.Configuration
    :members:

Clues
-----

.. autoclass:: hanabython.Clue
    :members:

Cards
-----

.. autoclass:: hanabython.Card
    :members:

.. autoclass:: hanabython.CardPublic
    :members:

Hands
-----

.. autoclass:: hanabython.Hand
    :members:

.. autoclass:: hanabython.HandPublic
    :members:

Draw Pile
---------

.. autoclass:: hanabython.DrawPile
    :members:

.. autoclass:: hanabython.DrawPilePublic
    :members:

Discard Pile
------------

.. autoclass:: hanabython.DiscardPile
    :members:

Board
-----

.. autoclass:: hanabython.Board
    :members:

Actions
-------

.. autoclass:: hanabython.Action
    :members:

.. autoclass:: hanabython.ActionDiscard
    :members:

.. autoclass:: hanabython.ActionPlay
    :members:

.. autoclass:: hanabython.ActionClue
    :members:

.. autoclass:: hanabython.ActionForfeit
    :members:

Players
-------

.. autoclass:: hanabython.Player
    :members:

.. autoclass:: hanabython.PlayerPuppet
    :members:

.. autoclass:: hanabython.PlayerBase
    :members:

.. autoclass:: hanabython.PlayerHumanText
    :members:

Game
----

.. autoclass:: hanabython.Game
    :members:

